# Start of  Bilko for Windows formula document to radiometrically correct Landsat-5 TM bands 
# 1-3 collected over the Turks and Caicos on 22 June 1990.
#
#	Formula document 1.
#	=================
#
#	Converting DN to at satellite spectral radiance (L) using formulae of the type:
#
#		Lmin + (Lmax/254 - Lmin/255) * @n ;
#
#	Input values
#	==========
#	Lmin: TM1 = -0.116, TM2 = -0.183, TM3 = -0.159
#	Lmax: TM1 = 15.996; TM2 = 31.776; TM3 = 24.394
#
	const Lmin1 = -0.116 ;
	const Lmin2 = -0.183 ;
	const Lmin3 = -0.159 ;

	const Lmax1 = 15.996 ;
	const Lmax2 = 31.776 ;
	const Lmax3 = 24.394 ;

#	Intermediate formulae for L for each TM band:
# 
#	Lmin1 + (Lmax1/254 - Lmin1/255)*@1;
#	Lmin2 + (Lmax2/254 - Lmin2/255)*@2;
#	Lmin3 + (Lmax3/254 - Lmin3/255)*@3;
#
#	Converting at satellite spectral radiance (L) to exoatmospheric reflectance
#
#	Input values
#	==========
#	pi = 3.141593
# 	d = 1.032829 astronomical units (JD = 173 for 22/6/90)
# 	SZ = 90-58 = 32	 32 = 0.5585 radians
#	ESUN: TM1 = 195.7, TM2 = 182.9, TM3 = 155.7 

	const pi =3.141593 ;
	const dsquared = 1.032829 ;
	const SZ = 0.5585 ;
	const ESUN1 = 195.7 ;
	const ESUN2 = 182.9 ;
	const ESUN3 =  155.7 ; 
#
#	Let at satellite spectral radiance = L  (see intermediate formulae above)
#
#	Converting L to exoatmospheric reflectance (ER)  with formulae of the type:
#
#		 pi * L * d / (ESUN * cos(SZ))  ;
#
#
#	ER1 = pi * (Lmin1 + (Lmax1/254 - Lmin1/255)*@1) * dsquared / (ESUN1 * cos(SZ)) ;
#	ER2 = pi * (Lmin2 + (Lmax2/254 - Lmin2/255)*@2) * dsquared / (ESUN2 * cos(SZ)) ;
#	ER3 = pi * (Lmin3 + (Lmax3/254 - Lmin3/255)*@3) * dsquared / (ESUN3 * cos(SZ)) ;


#
#	Formula document 2.
#	=================
#
# 	Stage 2 of atmospheric correction using 5S radiative transfer model outputs
#
#	Input values
#	==========
# 	AI = 1 / (Global gas transmittance * Total scattering transmittance)
#		TM1 = 1.2561, TM2 = 1.2344, TM3 = 1.1716
#
# 	BI = - Reflectance / Total scattering transmittance
#		TM1 = -0.0957, TM2 = -0.0539, TM3 = -0.0341
#
	const AI1 = 1.2561 ;
	const AI2 = 1.2344 ;
	const AI3 = 1.1716 ;

	const BI1 = -0.0957 ;
	const BI2 = -0.0539 ;
	const BI3 = -0.0341 ;

#	Let exoatmospheric reflectance = ERn where n=1-3  (i.e. images output by first formula document)
#
#	Converting exoatmsopheric reflectance to intermediate image Y with formulae of the type:
#
#		 AI * ER + BI;
#
#	Intermediate formulae for Y:
# 
#	AI1 * ER1 + BI1;
#	AI2 * ER2 + BI2;
#	AI3 * ER3 + BI3;
#
# 	Stage 3 of atmospheric correction using 5S radiative transfer model outputs
#
#	Input values
#	==========
# 	S = Spherical albedo: TM1 = 0.167, TM2 = 0.121, TM3 = 0.092
#
	const S1 = 0.167 ;
	const S2 = 0.121 ;
	const S3 = 0.092 ;


#	Let intermediate image  = Y  (see intermediate formulae above)
#
#	Converting Y to surface reflectance (on scale 0-1) with formulae of the type:
#
#		Y / (1 + S * Y)  ;
#
# 	Note that the intermediate formula for Y should appear in the equation twice.
#

#	(AI1 * ER1 + BI1) / (1 + S1 * (AI1 * ER1 + BI1) )  ;
#	(AI2 * ER2 + BI2) / (1 + S2 * (AI2 * ER2 + BI2) )  ;
#	(AI3 * ER3 + BI3) / (1 + S3 * (AI3 * ER3 + BI3) )  ;

# 	Substituting for ER1-3 with intermediate formulae above:

	 (AI1 *  (pi * (Lmin1 + (Lmax1/254 - Lmin1/255)*@1) * dsquared / (ESUN1 * cos(SZ))) + BI1) / 
	(1 + S1 * (AI1 * (pi * (Lmin1 + (Lmax1/254 - Lmin1/255)*@1) * dsquared / (ESUN1 * cos(SZ))) + BI1) )  ;

	 (AI2 * (pi * (Lmin2 + (Lmax2/254 - Lmin2/255)*@2) * dsquared / (ESUN2 * cos(SZ))) + BI2) / 
	(1 + S2 * (AI2 * (pi * (Lmin2 + (Lmax2/254 - Lmin2/255)*@2) * dsquared / (ESUN2 * cos(SZ))) + BI2) )  ;

	(AI3 * (pi * (Lmin3 + (Lmax3/254 - Lmin3/255)*@3) * dsquared / (ESUN3 * cos(SZ))) + BI3) / 
	(1 + S3 * (AI3 * (pi * (Lmin3 + (Lmax3/254 - Lmin3/255)*@3) * dsquared / (ESUN3 * cos(SZ))) + BI3) )  ;
